#
# spec file for package python-django-tastypie
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%{?sle15_python_module_pythons}
Name:           python-django-tastypie
Version:        0.14.6
Release:        bp156.1.2
Summary:        A webservice API framework layer for Django
License:        BSD-3-Clause
URL:            https://github.com/django-tastypie/django-tastypie
Source:         https://github.com/django-tastypie/django-tastypie/archive/v%{version}.tar.gz
# PATCH-FIX-UPSTREAM gh#django-tastypie/django-tastypie#1667
Patch0:         correct-assertion-methods.patch
BuildRequires:  %{python_module Django >= 1.11.0}
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module biplist}
BuildRequires:  %{python_module defusedxml}
BuildRequires:  %{python_module lxml}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module python-dateutil >= 2.1}
BuildRequires:  %{python_module python-mimeparse >= 0.1.4}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Django >= 1.11.0
Requires:       python-python-dateutil >= 2.1
Requires:       python-python-mimeparse >= 0.1.4
Recommends:     python-PyYAML
Recommends:     python-biplist
Recommends:     python-defusedxml
Recommends:     python-lxml
BuildArch:      noarch
%python_subpackages

%description
Tastypie is a webservice API framework for Django. It provides a
customizable abstraction for creating REST-style interfaces.

%prep
%autosetup -p1 -n django-tastypie-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# The tests are doing what is specified in tox.ini
%{python_expand export PYTHONPATH=${PWD}:${PWD}/tests/
django-admin-%{$python_bin_suffix} test -v 3 -p '*' core.tests --settings=settings_core
django-admin-%{$python_bin_suffix} test -v 3 basic.tests --settings=settings_basic
django-admin-%{$python_bin_suffix} test -v 3 related_resource.tests --settings=settings_related
django-admin-%{$python_bin_suffix} test -v 3 alphanumeric.tests --settings=settings_alphanumeric
django-admin-%{$python_bin_suffix} test -v 3 authorization.tests --settings=settings_authorization
django-admin-%{$python_bin_suffix} test -v 3 content_gfk.tests --settings=settings_content_gfk
django-admin-%{$python_bin_suffix} test -v 3 customuser.tests --settings=settings_customuser
django-admin-%{$python_bin_suffix} test -v 3 namespaced.tests --settings=settings_namespaced
django-admin-%{$python_bin_suffix} test -v 3 slashless.tests --settings=settings_slashless
django-admin-%{$python_bin_suffix} test -v 3 validation.tests --settings=settings_validation
}

%files %{python_files}
%license LICENSE
%doc AUTHORS *.rst docs/*.rst docs/release_notes/ docs/code/
%{python_sitelib}/tastypie
%{python_sitelib}/django_tastypie-%{version}.dist-info

%changelog
* Tue Mar 12 2024 Max Lin <mlin@suse.com>
- Add %%{?sle15_python_module_pythons}
* Wed Jan 31 2024 Steve Kowalik <steven.kowalik@suse.com>
- Add patch correct-assertion-methods.patch:
  * Use non-deprecated assertion methods.
- Switch to autosetup and pyproject macros.
- Stop using globbing in %%files.
* Mon Sep 18 2023 Dirk Müller <dmueller@suse.com>
- update to 0.14.6:
  * Remove unused mock library from test requirements
  * Django 4.2 compatibility
  * Fixed crash when missing CSRF token cookie in
    SessionAuthentication
  * Fix flake8, update docs, fix RTD builds
* Thu Jan 26 2023 John Vandenberg <jayvdb@gmail.com>
- Dropped pr_1642_chunk.patch and python-django-tastypie-no-mock.patch
  merged upstream
- Update to v0.4.15
  * Drops Python 2.5 support. Yes, this is a feature that will pave
    the way for Tastypie on Python 3 support.
  * Added TASTYPIE_ABSTRACT_APIKEY, which allows switching the ApiKey
    model out.
  * Better support for Django 1.5:
    + Removed deprecation warnings
    + Numerous custom User improvements
  * Expanded places use_in is used
  * Authorization is now only called once with a full bundle
  * Changed for_list to accept a boolean
  * Only save related models that have changed
  * Better exception reporting, especially in conjunction with Sentry
  * Configuration warning about defusedxml
  * Fixed a dependency in setup.py
  * Release notes became a thing.
  * Documentation updates
* Wed Oct  5 2022 John Vandenberg <jayvdb@gmail.com>
- Add pr_1642_chunk.patch for Django 4.1 support
* Wed May 11 2022 pgajdos@suse.com
- do not use python-mock for build
- added patches
  fix https://github.com/django-tastypie/django-tastypie/issues/1635
  + python-django-tastypie-no-mock.patch
* Fri Feb 25 2022 Matej Cepl <mcepl@suse.com>
- Update to 0.14.4:
  - Django 4.0 support
- Fix testing of the package.
- Remove upstreamed patch merged_pr_1624_chunk.patch
* Wed Jun  9 2021 John Vandenberg <jayvdb@gmail.com>
- Fix a failing test using a chunk of upstream PR 1624
  merged_pr_1624_chunk.patch
* Mon Feb 22 2021 John Vandenberg <jayvdb@gmail.com>
- Skip two tests failing on Tumbleweed Python 3.6
* Thu Jan  9 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.14.3:
  * no upstream changelog
* Sun Feb 24 2019 John Vandenberg <jayvdb@gmail.com>
- Add AUTHORS, other *.rst files, and docs/ to %%doc
- Update to v0.14.2
  * Added support for Django 2.1; minor bugs and regressions fixed.
    + Incorporates django-tastypie-django21.patch
  * Drops support for Django 1.8 LTS.
* Thu Aug 16 2018 jengelh@inai.de
- Replace useless description.
* Tue Aug 14 2018 tchvatal@suse.com
- Version update to 0.14.1:
  * Fixes to support latest django
- Run tests
- Add patch for django 2.1:
  * django-tastypie-django21.patch
* Fri Feb 26 2016 tbechtold@suse.com
- Require python-python-dateutil. package was renamed
* Wed Apr 22 2015 mcihar@suse.cz
- Update to version 0.12.1:
  * Drastic reworking of the test suite. (SHA: 95f57f7)
  * Fixed Travis to run Python 3.4 tests. (SHA: 7af528c)
  * Fixed a bug where URLs would be incorrectly handled if the ``api_name`` &
    ``resource_name`` were the same. (SHA: fd55aa3)
  * Fixed a test requirement for PyYAML. (SHA: b4f6531)
  * Added support for Django 1.7. (SHA: 7881bb6)
  * Documentation updates
* Mon Jul  7 2014 mcihar@suse.cz
- Update to verson 0.11.1
  + Fixes XSS
  + Fixes security issue in URL parsing
  + Many other bugfixes
* Sat Sep 28 2013 p.drouand@gmail.com
- Update to version 0.10
  + No changelog available
- Replace python-distribute with python-setuptools BuildRequires
* Mon Jul 15 2013 mcihar@suse.cz
- Update to version 0.9.15:
  * No changelog available
* Thu Feb 14 2013 p.drouand@gmail.com
- Update to version 0.9.12:
  * No changelog available
* Wed Mar 21 2012 saschpe@gmx.de
- Initial version
